@@ -2,14 +2,19 @@
 
 cd $(dirname $(realpath $0))
 
+chmod 400 id_rsa
 rm -f known_host ssh_log
 
 if [ "$1" != "term" ]; then
     options="-nT"
 fi
 
-for each in 1 2 3 4 5; do
-    sleep 1
+sleep 4
+
+for i in 1 2 3 4 5 6 7 8 9 10; do
+    echo The $i try...
+
+    sleep $i
     ssh test@localhost \
         -p 2435 \
         -i id_rsa \
@@ -28,4 +33,10 @@ for each in 1 2 3 4 5; do
     if [ $exit_code -eq 0 ]; then
         exit
     fi
+
+    sleep $i
 done
+
+echo Failed to start ssh
+cat *log
+exit 1
